@@ -10,7 +10,7 @@ from typing import List, Any
 
 logger = logging.getLogger(__name__)
 true_values = ('enabled', 'y', 'yes', 't', 'true', 'True', 'on', '1')
-false_values = ('disabled', 'n', 'no', 'f', 'false', 'False', 'off', '0')
+false_values = ('', None, 'disabled', 'n', 'no', 'f', 'false', 'False', 'off', '0')
 
 
 def recursive_str(data: Any) -> Any:
@@ -86,6 +86,6 @@ def random_password(size: int = 8) -> str:
     return ''.join(random.choice(alphabet) for i in range(size))
 
 
-class PrettyDefaultDict(defaultdict):
+class PrettyDefaultDict(defaultdict):  # type: ignore
     '''Beautiful (correct printing) dict using collections.defaultdict'''
     __repr__ = dict.__repr__
